@@ -13,6 +13,7 @@ Usage::
 """
 from typing import Any, Dict, List, Type
 
+from botocore.client import ClientMeta
 from botocore.exceptions import ClientError as Boto3ClientError
 
 from mypy_boto3_personalize_runtime.type_defs import (
@@ -31,14 +32,15 @@ class Exceptions:
 
 class PersonalizeRuntimeClient:
     """
-    [PersonalizeRuntime.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/personalize-runtime.html#PersonalizeRuntime.Client)
+    [PersonalizeRuntime.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/personalize-runtime.html#PersonalizeRuntime.Client)
     """
 
+    meta: ClientMeta
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.can_paginate)
         """
 
     def generate_presigned_url(
@@ -49,7 +51,7 @@ class PersonalizeRuntimeClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.generate_presigned_url)
         """
 
     def get_personalized_ranking(
@@ -61,7 +63,7 @@ class PersonalizeRuntimeClient:
         filterArn: str = None,
     ) -> GetPersonalizedRankingResponseTypeDef:
         """
-        [Client.get_personalized_ranking documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_personalized_ranking)
+        [Client.get_personalized_ranking documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_personalized_ranking)
         """
 
     def get_recommendations(
@@ -74,5 +76,5 @@ class PersonalizeRuntimeClient:
         filterArn: str = None,
     ) -> GetRecommendationsResponseTypeDef:
         """
-        [Client.get_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_recommendations)
+        [Client.get_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_recommendations)
         """
